@@ -3,11 +3,23 @@ import sys
 from dataclasses import dataclass
 from enum import Enum, unique
 from pathlib import Path
-from typing import IO, Any, AnyStr, Callable, Iterable, Optional, Sequence, TypeVar, Union, cast
+from typing import (
+    IO,
+    Any,
+    AnyStr,
+    Callable,
+    Iterable,
+    Optional,
+    Sequence,
+    TypeVar,
+    Union,
+    cast,
+)
 
 import click
 import pluggy
 import tomli_w
+
 from robotcode.core.utils.dataclasses import as_dict, as_json
 
 __all__ = [
@@ -79,21 +91,24 @@ class Application:
 
     @property
     def colored(self) -> bool:
-        return self.config.colored_output in [ColoredOutput.AUTO, ColoredOutput.YES]
+        return self.config.colored_output in [
+            ColoredOutput.AUTO,
+            ColoredOutput.YES,
+        ]
 
     def verbose(
         self,
         message: Union[str, Callable[[], Any], None],
         file: Optional[IO[AnyStr]] = None,
-        nl: bool = True,
-        err: bool = True,
+        nl: Optional[bool] = True,
+        err: Optional[bool] = True,
     ) -> None:
         if self.config.verbose:
             click.secho(
                 message() if callable(message) else message,
                 file=file,
-                nl=nl,
-                err=err,
+                nl=nl if nl is not None else True,
+                err=err if err is not None else True,
                 color=self.colored,
                 fg="bright_black",
             )
@@ -102,20 +117,38 @@ class Application:
         self,
         message: Union[str, Callable[[], Any], None],
         file: Optional[IO[AnyStr]] = None,
-        nl: bool = True,
-        err: bool = False,
+        nl: Optional[bool] = True,
+        err: Optional[bool] = True,
     ) -> None:
         click.secho(
-            f"WARNING: {message() if callable(message) else message}",
+            f"[ {click.style('WARN', fg='yellow')} ] {message() if callable(message) else message}",
             file=file,
-            nl=nl,
-            err=err,
+            nl=nl if nl is not None else True,
+            err=err if err is not None else True,
             color=self.colored,
             fg="bright_yellow",
         )
 
+    def error(
+        self,
+        message: Union[str, Callable[[], Any], None],
+        file: Optional[IO[AnyStr]] = None,
+        nl: Optional[bool] = True,
+        err: Optional[bool] = True,
+    ) -> None:
+        click.secho(
+            f"[ {click.style('ERROR', fg='red')} ] {message() if callable(message) else message}",
+            file=file,
+            nl=nl if nl is not None else True,
+            err=err if err is not None else True,
+            color=self.colored,
+        )
+
     def print_data(
-        self, data: Any, remove_defaults: bool = True, default_output_format: Optional[OutputFormat] = None
+        self,
+        data: Any,
+        remove_defaults: bool = True,
+        default_output_format: Optional[OutputFormat] = None,
     ) -> None:
         format = self.config.output_format or default_output_format or OutputFormat.TEXT
 
@@ -124,14 +157,16 @@ class Application:
             text = tomli_w.dumps(
                 as_dict(data, remove_defaults=remove_defaults)
                 if dataclasses.is_dataclass(data)
-                else data
-                if isinstance(data, dict)
-                else {data: data}
+                else data if isinstance(data, dict) else {data: data}
             )
 
         if text is None:
             if format in [OutputFormat.JSON, OutputFormat.JSON_INDENT]:
-                text = as_json(data, indent=format == OutputFormat.JSON_INDENT, compact=format == OutputFormat.TEXT)
+                text = as_json(
+                    data,
+                    indent=format == OutputFormat.JSON_INDENT,
+                    compact=format == OutputFormat.TEXT,
+                )
             else:
                 text = str(data)
 
@@ -238,7 +273,10 @@ class Application:
             )
             click.echo(text, color=color if color is not None else self.colored)
         else:
-            click.echo_via_pager(text_or_generator, color=color if color is not None else self.colored)
+            click.echo_via_pager(
+                text_or_generator,
+                color=color if color is not None else self.colored,
+            )
 
     def keyboard_interrupt(self) -> None:
         self.verbose("Aborted!", file=sys.stderr)
